package com.pahimar.ee3.recipe;

import com.pahimar.ee3.api.recipe.RecipeRegistryProxy;
import com.pahimar.ee3.util.ItemStackUtils;
import net.minecraft.init.Items;
import net.minecraft.init.MobEffects;
import net.minecraft.init.PotionTypes;
import net.minecraft.item.ItemStack;
import net.minecraft.potion.PotionEffect;
import net.minecraft.potion.PotionType;
import net.minecraft.potion.PotionUtils;
import net.minecraftforge.fluids.Fluid;
import net.minecraftforge.fluids.FluidRegistry;
import net.minecraftforge.fluids.FluidStack;

public class RecipesPotions {

    private static final FluidStack REAGENT_WATER = new FluidStack(FluidRegistry.WATER, Fluid.BUCKET_VOLUME);
    private static final ItemStack REAGENT_NETHER_WART = new ItemStack(Items.NETHER_WART);
    private static final ItemStack REAGENT_GLOWSTONE_DUST = new ItemStack(Items.GLOWSTONE_DUST);
    private static final ItemStack REAGENT_REDSTONE_DUST = new ItemStack(Items.REDSTONE);
    private static final ItemStack REAGENT_GUNPOWDER = new ItemStack(Items.GUNPOWDER);
    private static final ItemStack REAGENT_GOLDEN_CARROT = new ItemStack(Items.GOLDEN_CARROT);
    private static final ItemStack REAGENT_MAGMA_CREAM = new ItemStack(Items.MAGMA_CREAM);
    private static final ItemStack REAGENT_SUGAR = new ItemStack(Items.SUGAR);
    private static final ItemStack REAGENT_GLISTERING_MELON = new ItemStack(Items.SPECKLED_MELON);
    private static final ItemStack REAGENT_SPIDER_EYE = new ItemStack(Items.SPIDER_EYE);
    private static final ItemStack REAGENT_GHAST_TEAR = new ItemStack(Items.GHAST_TEAR);
    private static final ItemStack REAGENT_FERMENTED_SPIDER_EYE = new ItemStack(Items.FERMENTED_SPIDER_EYE);
    private static final ItemStack REAGENT_BLAZE_POWDER = new ItemStack(Items.BLAZE_POWDER);
    private static final ItemStack REAGENT_PUFFERFISH = new ItemStack(Items.FISH, 1, 3);
    private static final ItemStack REAGENT_RABBITS_FOOT = new ItemStack(Items.RABBIT_FOOT);
    private static final ItemStack REAGENT_DRAGONS_BREATH = new ItemStack(Items.DRAGON_BREATH);

    // Regular Potions
    private static final ItemStack BOTTLE_EMPTY = new ItemStack(Items.GLASS_BOTTLE);
    public static final ItemStack BOTTLE_WATER = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.WATER);
    public static final ItemStack POTION_UNCRAFTABLE = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.EMPTY);
    public static final ItemStack POTION_MUNDANE = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.MUNDANE);
    public static final ItemStack POTION_THICK = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.THICK);
    public static final ItemStack POTION_AWKWARD = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.AWKWARD);
    public static final ItemStack POTION_NIGHT_VISION = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.NIGHT_VISION);
    public static final ItemStack POTION_NIGHT_VISION_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_NIGHT_VISION);
    public static final ItemStack POTION_INVISIBILITY = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.INVISIBILITY);
    public static final ItemStack POTION_INVISIBILITY_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_INVISIBILITY);
    public static final ItemStack POTION_LEAPING = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LEAPING);
    public static final ItemStack POTION_LEAPING_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_LEAPING);
    public static final ItemStack POTION_LEAPING_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.STRONG_LEAPING);
    public static final ItemStack POTION_FIRE_RESISTANCE = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.FIRE_RESISTANCE);
    public static final ItemStack POTION_FIRE_RESISTANCE_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_FIRE_RESISTANCE);
    public static final ItemStack POTION_SWIFTNESS = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.SWIFTNESS);
    public static final ItemStack POTION_SWIFTNESS_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_SWIFTNESS);
    public static final ItemStack POTION_SWIFTNESS_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.STRONG_SWIFTNESS);
    public static final ItemStack POTION_SLOWNESS = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.SLOWNESS);
    public static final ItemStack POTION_SLOWNESS_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_SLOWNESS);
    public static final ItemStack POTION_WATER_BREATHING = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.WATER_BREATHING);
    public static final ItemStack POTION_WATER_BREATHING_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_WATER_BREATHING);
    public static final ItemStack POTION_HEALING = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.HEALING);
    public static final ItemStack POTION_HEALING_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.STRONG_HEALING);
    public static final ItemStack POTION_HARMING = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.HARMING);
    public static final ItemStack POTION_HARMING_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.STRONG_HARMING);
    public static final ItemStack POTION_POISON = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.POISON);
    public static final ItemStack POTION_POISON_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_POISON);
    public static final ItemStack POTION_POISON_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.STRONG_POISON);
    public static final ItemStack POTION_REGENERATION = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.REGENERATION);
    public static final ItemStack POTION_REGENERATION_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_REGENERATION);
    public static final ItemStack POTION_REGENERATION_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.STRONG_REGENERATION);
    public static final ItemStack POTION_STRENGTH = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.STRENGTH);
    public static final ItemStack POTION_STRENGTH_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_STRENGTH);
    public static final ItemStack POTION_STRENGTH_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.STRONG_STRENGTH);
    public static final ItemStack POTION_WEAKNESS = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.WEAKNESS);
    public static final ItemStack POTION_WEAKNESS_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), PotionTypes.LONG_WEAKNESS);
    public static final ItemStack POTION_LUCK = PotionUtils.addPotionToItemStack(new ItemStack(Items.POTIONITEM), new PotionType("luck", new PotionEffect(MobEffects.LUCK, 6000)));

    // Splash Potions
    public static final ItemStack SPLASH_BOTTLE_WATER = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.WATER);
    public static final ItemStack SPLASH_POTION_UNCRAFTABLE = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.EMPTY);
    public static final ItemStack SPLASH_POTION_MUNDANE = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.MUNDANE);
    public static final ItemStack SPLASH_POTION_THICK = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.THICK);
    public static final ItemStack SPLASH_POTION_AWKWARD = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.AWKWARD);
    public static final ItemStack SPLASH_POTION_NIGHT_VISION = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.NIGHT_VISION);
    public static final ItemStack SPLASH_POTION_NIGHT_VISION_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_NIGHT_VISION);
    public static final ItemStack SPLASH_POTION_INVISIBILITY = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.INVISIBILITY);
    public static final ItemStack SPLASH_POTION_INVISIBILITY_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_INVISIBILITY);
    public static final ItemStack SPLASH_POTION_LEAPING = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LEAPING);
    public static final ItemStack SPLASH_POTION_LEAPING_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_LEAPING);
    public static final ItemStack SPLASH_POTION_LEAPING_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.STRONG_LEAPING);
    public static final ItemStack SPLASH_POTION_FIRE_RESISTANCE = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.FIRE_RESISTANCE);
    public static final ItemStack SPLASH_POTION_FIRE_RESISTANCE_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_FIRE_RESISTANCE);
    public static final ItemStack SPLASH_POTION_SWIFTNESS = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.SWIFTNESS);
    public static final ItemStack SPLASH_POTION_SWIFTNESS_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_SWIFTNESS);
    public static final ItemStack SPLASH_POTION_SWIFTNESS_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.STRONG_SWIFTNESS);
    public static final ItemStack SPLASH_POTION_SLOWNESS = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.SLOWNESS);
    public static final ItemStack SPLASH_POTION_SLOWNESS_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_SLOWNESS);
    public static final ItemStack SPLASH_POTION_WATER_BREATHING = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.WATER_BREATHING);
    public static final ItemStack SPLASH_POTION_WATER_BREATHING_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_WATER_BREATHING);
    public static final ItemStack SPLASH_POTION_HEALING = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.HEALING);
    public static final ItemStack SPLASH_POTION_HEALING_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.STRONG_HEALING);
    public static final ItemStack SPLASH_POTION_HARMING = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.HARMING);
    public static final ItemStack SPLASH_POTION_HARMING_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.STRONG_HARMING);
    public static final ItemStack SPLASH_POTION_POISON = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.POISON);
    public static final ItemStack SPLASH_POTION_POISON_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_POISON);
    public static final ItemStack SPLASH_POTION_POISON_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.STRONG_POISON);
    public static final ItemStack SPLASH_POTION_REGENERATION = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.REGENERATION);
    public static final ItemStack SPLASH_POTION_REGENERATION_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_REGENERATION);
    public static final ItemStack SPLASH_POTION_REGENERATION_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.STRONG_REGENERATION);
    public static final ItemStack SPLASH_POTION_STRENGTH = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.STRENGTH);
    public static final ItemStack SPLASH_POTION_STRENGTH_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_STRENGTH);
    public static final ItemStack SPLASH_POTION_STRENGTH_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.STRONG_STRENGTH);
    public static final ItemStack SPLASH_POTION_WEAKNESS = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.WEAKNESS);
    public static final ItemStack SPLASH_POTION_WEAKNESS_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), PotionTypes.LONG_WEAKNESS);
    public static final ItemStack SPLASH_POTION_LUCK = PotionUtils.addPotionToItemStack(new ItemStack(Items.SPLASH_POTION), new PotionType("luck", new PotionEffect(MobEffects.LUCK, 6000)));

    // Lingering Potions
    public static final ItemStack LINGERING_BOTTLE_WATER = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.WATER);
    public static final ItemStack LINGERING_POTION_UNCRAFTABLE = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.EMPTY);
    public static final ItemStack LINGERING_POTION_MUNDANE = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.MUNDANE);
    public static final ItemStack LINGERING_POTION_THICK = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.THICK);
    public static final ItemStack LINGERING_POTION_AWKWARD = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.AWKWARD);
    public static final ItemStack LINGERING_POTION_NIGHT_VISION = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.NIGHT_VISION);
    public static final ItemStack LINGERING_POTION_NIGHT_VISION_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_NIGHT_VISION);
    public static final ItemStack LINGERING_POTION_INVISIBILITY = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.INVISIBILITY);
    public static final ItemStack LINGERING_POTION_INVISIBILITY_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_INVISIBILITY);
    public static final ItemStack LINGERING_POTION_LEAPING = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LEAPING);
    public static final ItemStack LINGERING_POTION_LEAPING_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_LEAPING);
    public static final ItemStack LINGERING_POTION_LEAPING_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.STRONG_LEAPING);
    public static final ItemStack LINGERING_POTION_FIRE_RESISTANCE = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.FIRE_RESISTANCE);
    public static final ItemStack LINGERING_POTION_FIRE_RESISTANCE_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_FIRE_RESISTANCE);
    public static final ItemStack LINGERING_POTION_SWIFTNESS = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.SWIFTNESS);
    public static final ItemStack LINGERING_POTION_SWIFTNESS_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_SWIFTNESS);
    public static final ItemStack LINGERING_POTION_SWIFTNESS_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.STRONG_SWIFTNESS);
    public static final ItemStack LINGERING_POTION_SLOWNESS = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.SLOWNESS);
    public static final ItemStack LINGERING_POTION_SLOWNESS_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_SLOWNESS);
    public static final ItemStack LINGERING_POTION_WATER_BREATHING = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.WATER_BREATHING);
    public static final ItemStack LINGERING_POTION_WATER_BREATHING_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_WATER_BREATHING);
    public static final ItemStack LINGERING_POTION_HEALING = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.HEALING);
    public static final ItemStack LINGERING_POTION_HEALING_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.STRONG_HEALING);
    public static final ItemStack LINGERING_POTION_HARMING = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.HARMING);
    public static final ItemStack LINGERING_POTION_HARMING_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.STRONG_HARMING);
    public static final ItemStack LINGERING_POTION_POISON = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.POISON);
    public static final ItemStack LINGERING_POTION_POISON_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_POISON);
    public static final ItemStack LINGERING_POTION_POISON_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.STRONG_POISON);
    public static final ItemStack LINGERING_POTION_REGENERATION = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.REGENERATION);
    public static final ItemStack LINGERING_POTION_REGENERATION_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_REGENERATION);
    public static final ItemStack LINGERING_POTION_REGENERATION_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.STRONG_REGENERATION);
    public static final ItemStack LINGERING_POTION_STRENGTH = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.STRENGTH);
    public static final ItemStack LINGERING_POTION_STRENGTH_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_STRENGTH);
    public static final ItemStack LINGERING_POTION_STRENGTH_STRONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.STRONG_STRENGTH);
    public static final ItemStack LINGERING_POTION_WEAKNESS = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.WEAKNESS);
    public static final ItemStack LINGERING_POTION_WEAKNESS_LONG = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), PotionTypes.LONG_WEAKNESS);
    public static final ItemStack LINGERING_POTION_LUCK = PotionUtils.addPotionToItemStack(new ItemStack(Items.LINGERING_POTION), new PotionType("luck", new PotionEffect(MobEffects.LUCK, 6000)));

    public static void registerRecipes() {

        registerRegularPotionRecipes();
        registerSplashPotionRecipes();
        registerLingeringPotionRecipes();
    }

    private static void registerRegularPotionRecipes() {

        RecipeRegistryProxy.addRecipe(BOTTLE_WATER, BOTTLE_EMPTY, REAGENT_WATER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_MUNDANE, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_MUNDANE, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_RABBITS_FOOT);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_MUNDANE, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_SUGAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_MUNDANE, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_MAGMA_CREAM);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_MUNDANE, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_BLAZE_POWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_MUNDANE, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_GLISTERING_MELON);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_MUNDANE, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_GHAST_TEAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_MUNDANE, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_THICK, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_AWKWARD, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_NETHER_WART);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_NIGHT_VISION, 3), ItemStackUtils.clone(POTION_AWKWARD, 3), REAGENT_GOLDEN_CARROT);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_NIGHT_VISION_LONG, 3), ItemStackUtils.clone(POTION_NIGHT_VISION, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_INVISIBILITY, 3), ItemStackUtils.clone(POTION_NIGHT_VISION, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_INVISIBILITY_LONG, 3), ItemStackUtils.clone(POTION_INVISIBILITY, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_INVISIBILITY_LONG, 3), ItemStackUtils.clone(POTION_NIGHT_VISION_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_LEAPING, 3), ItemStackUtils.clone(POTION_AWKWARD, 3), REAGENT_RABBITS_FOOT);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_LEAPING_LONG, 3), ItemStackUtils.clone(POTION_LEAPING, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_LEAPING_STRONG, 3), ItemStackUtils.clone(POTION_LEAPING, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_FIRE_RESISTANCE, 3), ItemStackUtils.clone(POTION_AWKWARD, 3), REAGENT_MAGMA_CREAM);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_FIRE_RESISTANCE_LONG, 3), ItemStackUtils.clone(POTION_FIRE_RESISTANCE, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_SWIFTNESS, 3), ItemStackUtils.clone(POTION_AWKWARD, 3), REAGENT_SUGAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_SWIFTNESS_LONG, 3), ItemStackUtils.clone(POTION_SWIFTNESS, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_SWIFTNESS_STRONG, 3), ItemStackUtils.clone(POTION_SWIFTNESS, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_SLOWNESS, 3), ItemStackUtils.clone(POTION_LEAPING, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_SLOWNESS, 3), ItemStackUtils.clone(POTION_SWIFTNESS, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_SLOWNESS_LONG, 3), ItemStackUtils.clone(POTION_LEAPING_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_SLOWNESS_LONG, 3), ItemStackUtils.clone(POTION_SWIFTNESS_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_WATER_BREATHING, 3), ItemStackUtils.clone(POTION_AWKWARD, 3), REAGENT_PUFFERFISH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_WATER_BREATHING_LONG, 3), ItemStackUtils.clone(POTION_WATER_BREATHING, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_HEALING, 3), ItemStackUtils.clone(POTION_AWKWARD, 3), REAGENT_GLISTERING_MELON);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_HEALING_STRONG, 3), ItemStackUtils.clone(POTION_HEALING, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_HARMING, 3), ItemStackUtils.clone(POTION_HEALING, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_HARMING, 3), ItemStackUtils.clone(POTION_POISON, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_HARMING, 3), ItemStackUtils.clone(POTION_POISON_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_HARMING_STRONG, 3), ItemStackUtils.clone(POTION_HEALING_STRONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_HARMING_STRONG, 3), ItemStackUtils.clone(POTION_HARMING, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_HARMING_STRONG, 3), ItemStackUtils.clone(POTION_POISON_STRONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_POISON, 3), ItemStackUtils.clone(POTION_AWKWARD, 3), REAGENT_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_POISON_LONG, 3), ItemStackUtils.clone(POTION_POISON, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_POISON_STRONG, 3), ItemStackUtils.clone(POTION_POISON, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_REGENERATION, 3), ItemStackUtils.clone(POTION_AWKWARD, 3), REAGENT_GHAST_TEAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_REGENERATION_LONG, 3), ItemStackUtils.clone(POTION_REGENERATION, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_REGENERATION_STRONG, 3), ItemStackUtils.clone(POTION_REGENERATION, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_STRENGTH, 3), ItemStackUtils.clone(POTION_AWKWARD, 3), REAGENT_BLAZE_POWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_STRENGTH_LONG, 3), ItemStackUtils.clone(POTION_STRENGTH, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_STRENGTH_STRONG, 3), ItemStackUtils.clone(POTION_STRENGTH, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_WEAKNESS, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(POTION_WEAKNESS_LONG, 3), ItemStackUtils.clone(POTION_WEAKNESS, 3), REAGENT_REDSTONE_DUST);
    }

    private static void registerSplashPotionRecipes() {

        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_UNCRAFTABLE, 3), ItemStackUtils.clone(POTION_UNCRAFTABLE, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), ItemStackUtils.clone(BOTTLE_WATER, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_MUNDANE, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_SUGAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_MUNDANE, 3), ItemStackUtils.clone(POTION_MUNDANE, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_MUNDANE, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_MUNDANE, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_MUNDANE, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_GLISTERING_MELON);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_MUNDANE, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_BLAZE_POWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_MUNDANE, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_RABBITS_FOOT);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_MUNDANE, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_GHAST_TEAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_MUNDANE, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_MAGMA_CREAM);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_THICK, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_THICK, 3), ItemStackUtils.clone(POTION_THICK, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_NETHER_WART);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), ItemStackUtils.clone(POTION_AWKWARD, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_NIGHT_VISION, 3), ItemStackUtils.clone(POTION_NIGHT_VISION, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_NIGHT_VISION, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_GOLDEN_CARROT);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_NIGHT_VISION_LONG, 3), ItemStackUtils.clone(POTION_NIGHT_VISION_LONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_NIGHT_VISION_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_NIGHT_VISION, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_INVISIBILITY, 3), ItemStackUtils.clone(POTION_INVISIBILITY, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_INVISIBILITY, 3), ItemStackUtils.clone(SPLASH_POTION_NIGHT_VISION, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_INVISIBILITY_LONG, 3), ItemStackUtils.clone(POTION_INVISIBILITY_LONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_INVISIBILITY_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_NIGHT_VISION_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_INVISIBILITY_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_INVISIBILITY, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_LEAPING, 3), ItemStackUtils.clone(POTION_LEAPING, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_LEAPING, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_RABBITS_FOOT);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_LEAPING_LONG, 3), ItemStackUtils.clone(POTION_LEAPING_LONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_LEAPING_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_LEAPING, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_LEAPING_STRONG, 3), ItemStackUtils.clone(POTION_LEAPING_STRONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_LEAPING_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_LEAPING, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_FIRE_RESISTANCE, 3), ItemStackUtils.clone(POTION_FIRE_RESISTANCE, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_FIRE_RESISTANCE, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_MAGMA_CREAM);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_FIRE_RESISTANCE_LONG, 3), ItemStackUtils.clone(POTION_FIRE_RESISTANCE_LONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_FIRE_RESISTANCE_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_FIRE_RESISTANCE, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS, 3), ItemStackUtils.clone(POTION_SWIFTNESS, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_SUGAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS_LONG, 3), ItemStackUtils.clone(POTION_SWIFTNESS_LONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS_STRONG, 3), ItemStackUtils.clone(POTION_SWIFTNESS_STRONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SLOWNESS, 3), ItemStackUtils.clone(POTION_SLOWNESS, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SLOWNESS, 3), ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SLOWNESS_LONG, 3), ItemStackUtils.clone(POTION_SLOWNESS_LONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SLOWNESS_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_SLOWNESS, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SLOWNESS_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_SLOWNESS_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_LEAPING_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_WATER_BREATHING, 3), ItemStackUtils.clone(POTION_WATER_BREATHING, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_WATER_BREATHING, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_PUFFERFISH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_WATER_BREATHING_LONG, 3), ItemStackUtils.clone(POTION_WATER_BREATHING_LONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_WATER_BREATHING_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_WATER_BREATHING, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HEALING, 3), ItemStackUtils.clone(POTION_HEALING, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HEALING, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_GLISTERING_MELON);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HEALING_STRONG, 3), ItemStackUtils.clone(POTION_HEALING_STRONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HEALING_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_HEALING, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HARMING, 3), ItemStackUtils.clone(SPLASH_POTION_HEALING, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HARMING, 3), ItemStackUtils.clone(SPLASH_POTION_POISON, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HARMING, 3), ItemStackUtils.clone(POTION_HARMING, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HARMING, 3), ItemStackUtils.clone(SPLASH_POTION_POISON_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HARMING_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_HEALING_STRONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HARMING_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_HARMING, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HARMING_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_POISON_STRONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_HARMING_STRONG, 3), ItemStackUtils.clone(POTION_HARMING_STRONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_POISON, 3), ItemStackUtils.clone(POTION_POISON, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_POISON, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_POISON_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_POISON, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_POISON_LONG, 3), ItemStackUtils.clone(POTION_POISON_LONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_POISON_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_POISON, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_POISON_STRONG, 3), ItemStackUtils.clone(POTION_POISON_STRONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_REGENERATION, 3), ItemStackUtils.clone(POTION_REGENERATION, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_REGENERATION, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_GHAST_TEAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_REGENERATION_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_REGENERATION, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_REGENERATION_LONG, 3), ItemStackUtils.clone(POTION_REGENERATION_LONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_REGENERATION_STRONG, 3), ItemStackUtils.clone(POTION_REGENERATION_STRONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_REGENERATION_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_REGENERATION, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_STRENGTH, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_BLAZE_POWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_STRENGTH, 3), ItemStackUtils.clone(POTION_STRENGTH, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_STRENGTH_LONG, 3), ItemStackUtils.clone(POTION_STRENGTH_LONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_STRENGTH_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_STRENGTH, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_STRENGTH_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_STRENGTH, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_STRENGTH_STRONG, 3), ItemStackUtils.clone(POTION_STRENGTH_STRONG, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_WEAKNESS, 3), ItemStackUtils.clone(POTION_WEAKNESS, 3), REAGENT_GUNPOWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_WEAKNESS, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_WEAKNESS_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_WEAKNESS, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(SPLASH_POTION_WEAKNESS_LONG, 3), ItemStackUtils.clone(POTION_WEAKNESS_LONG, 3), REAGENT_GUNPOWDER);
    }

    private static void registerLingeringPotionRecipes() {

        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_UNCRAFTABLE, 3), ItemStackUtils.clone(SPLASH_POTION_UNCRAFTABLE, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), ItemStackUtils.clone(SPLASH_BOTTLE_WATER, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_MUNDANE, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_GLISTERING_MELON);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_MUNDANE, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_RABBITS_FOOT);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_MUNDANE, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_BLAZE_POWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_MUNDANE, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_MUNDANE, 3), ItemStackUtils.clone(SPLASH_POTION_MUNDANE, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_MUNDANE, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_SUGAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_MUNDANE, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_MUNDANE, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_GHAST_TEAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_MUNDANE, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_MAGMA_CREAM);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_THICK, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_THICK, 3), ItemStackUtils.clone(SPLASH_POTION_THICK, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), ItemStackUtils.clone(SPLASH_POTION_AWKWARD, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_NETHER_WART);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_NIGHT_VISION, 3), ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), REAGENT_GOLDEN_CARROT);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_NIGHT_VISION, 3), ItemStackUtils.clone(SPLASH_POTION_NIGHT_VISION, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_NIGHT_VISION_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_NIGHT_VISION, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_NIGHT_VISION_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_NIGHT_VISION_LONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_INVISIBILITY, 3), ItemStackUtils.clone(LINGERING_POTION_NIGHT_VISION, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_INVISIBILITY, 3), ItemStackUtils.clone(SPLASH_POTION_INVISIBILITY, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_INVISIBILITY_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_INVISIBILITY_LONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_INVISIBILITY_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_NIGHT_VISION_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_INVISIBILITY_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_INVISIBILITY, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_LEAPING, 3), ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), REAGENT_RABBITS_FOOT);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_LEAPING, 3), ItemStackUtils.clone(SPLASH_POTION_LEAPING, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_LEAPING_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_LEAPING_LONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_LEAPING_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_LEAPING, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_LEAPING_STRONG, 3), ItemStackUtils.clone(LINGERING_POTION_LEAPING, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_LEAPING_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_LEAPING_STRONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_FIRE_RESISTANCE, 3), ItemStackUtils.clone(SPLASH_POTION_FIRE_RESISTANCE, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_FIRE_RESISTANCE, 3), ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), REAGENT_MAGMA_CREAM);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_FIRE_RESISTANCE_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_FIRE_RESISTANCE_LONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_FIRE_RESISTANCE_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_FIRE_RESISTANCE, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SWIFTNESS, 3), ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), REAGENT_SUGAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SWIFTNESS, 3), ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SWIFTNESS_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_SWIFTNESS, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SWIFTNESS_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS_LONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SWIFTNESS_STRONG, 3), ItemStackUtils.clone(LINGERING_POTION_SWIFTNESS, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SWIFTNESS_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_SWIFTNESS_STRONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SLOWNESS, 3), ItemStackUtils.clone(SPLASH_POTION_SLOWNESS, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SLOWNESS, 3), ItemStackUtils.clone(LINGERING_POTION_SWIFTNESS, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SLOWNESS, 3), ItemStackUtils.clone(LINGERING_POTION_LEAPING, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SLOWNESS_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_SLOWNESS_LONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SLOWNESS_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_SLOWNESS, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SLOWNESS_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_LEAPING_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_SLOWNESS_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_SWIFTNESS_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_WATER_BREATHING, 3), ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), REAGENT_PUFFERFISH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_WATER_BREATHING, 3), ItemStackUtils.clone(SPLASH_POTION_WATER_BREATHING, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_WATER_BREATHING_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_WATER_BREATHING, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_WATER_BREATHING_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_WATER_BREATHING_LONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HEALING, 3), ItemStackUtils.clone(SPLASH_POTION_HEALING, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HEALING, 3), ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), REAGENT_GLISTERING_MELON);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HEALING_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_HEALING_STRONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HEALING_STRONG, 3), ItemStackUtils.clone(LINGERING_POTION_HEALING, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HARMING, 3), ItemStackUtils.clone(LINGERING_POTION_POISON, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HARMING, 3), ItemStackUtils.clone(LINGERING_POTION_HEALING, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HARMING, 3), ItemStackUtils.clone(SPLASH_POTION_HARMING, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HARMING, 3), ItemStackUtils.clone(LINGERING_POTION_POISON_LONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HARMING_STRONG, 3), ItemStackUtils.clone(LINGERING_POTION_HARMING, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HARMING_STRONG, 3), ItemStackUtils.clone(LINGERING_POTION_HEALING_STRONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HARMING_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_HARMING_STRONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_HARMING_STRONG, 3), ItemStackUtils.clone(LINGERING_POTION_POISON_STRONG, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_POISON, 3), ItemStackUtils.clone(SPLASH_POTION_POISON, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_POISON, 3), ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), REAGENT_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_POISON_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_POISON_LONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_POISON_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_POISON_LONG, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_POISON_STRONG, 3), ItemStackUtils.clone(LINGERING_POTION_POISON, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_POISON_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_POISON_STRONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_REGENERATION, 3), ItemStackUtils.clone(SPLASH_POTION_REGENERATION, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_REGENERATION, 3), ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), REAGENT_GHAST_TEAR);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_REGENERATION_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_REGENERATION, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_REGENERATION_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_REGENERATION_LONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_REGENERATION_STRONG, 3), ItemStackUtils.clone(LINGERING_POTION_REGENERATION, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_REGENERATION_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_REGENERATION_STRONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_STRENGTH, 3), ItemStackUtils.clone(SPLASH_POTION_STRENGTH, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_STRENGTH, 3), ItemStackUtils.clone(LINGERING_POTION_AWKWARD, 3), REAGENT_BLAZE_POWDER);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_STRENGTH_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_STRENGTH, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_STRENGTH_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_STRENGTH_LONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_STRENGTH_STRONG, 3), ItemStackUtils.clone(SPLASH_POTION_STRENGTH_STRONG, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_STRENGTH_STRONG, 3), ItemStackUtils.clone(LINGERING_POTION_STRENGTH, 3), REAGENT_GLOWSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_WEAKNESS, 3), ItemStackUtils.clone(SPLASH_POTION_WEAKNESS, 3), REAGENT_DRAGONS_BREATH);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_WEAKNESS, 3), ItemStackUtils.clone(LINGERING_BOTTLE_WATER, 3), REAGENT_FERMENTED_SPIDER_EYE);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_WEAKNESS_LONG, 3), ItemStackUtils.clone(LINGERING_POTION_WEAKNESS, 3), REAGENT_REDSTONE_DUST);
        RecipeRegistryProxy.addRecipe(ItemStackUtils.clone(LINGERING_POTION_WEAKNESS_LONG, 3), ItemStackUtils.clone(SPLASH_POTION_WEAKNESS_LONG, 3), REAGENT_DRAGONS_BREATH);
    }
}
